==> angelssmelting_0.3.5.zip: angelssmelting_0.3.5/prototypes/items/angels-aluminium.lua <==
data:extend(
{
  {
    type = "item",
    name = "bauxite-ore",
    icon = "__angelssmelting__/graphics/icons/ore-bauxite.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-aluminium",
    order = "a",
    stack_size = 200
  },
  {
    type = "item",
    name = "processed-aluminium",
    icon = "__angelssmelting__/graphics/icons/processed-aluminium.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-aluminium",
    order = "b",
    stack_size = 200
  },
  {
    type = "item",
    name = "pellet-aluminium",
    icon = "__angelssmelting__/graphics/icons/pellet-aluminium.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-aluminium",
    order = "c",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-sodium-aluminate",
    icon = "__angelssmelting__/graphics/icons/solid-sodium-aluminate.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-aluminium",
    order = "d",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-aluminium-hydroxide",
    icon = "__angelssmelting__/graphics/icons/solid-aluminium-hydroxide.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-aluminium",
    order = "e",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-aluminium-oxide",
    icon = "__angelssmelting__/graphics/icons/solid-aluminium-oxide.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-aluminium",
    order = "f",
    stack_size = 200
  },
  {
    type = "item",
    name = "ingot-aluminium",
    icon = "__angelssmelting__/graphics/icons/ingot-aluminium.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-aluminium",
    order = "g",
    stack_size = 200
  },
  {
    type = "item",
    name = "powder-aluminium",
    icon = "__angelssmelting__/graphics/icons/powder-aluminium.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-aluminium",
    order = "h",
    stack_size = 200
  },
  {
    type = "fluid",
    name = "liquid-molten-aluminium",
    icon = "__angelssmelting__/graphics/icons/molten-aluminium.png",
	default_temperature = 100,
    heat_capacity = "0KJ",
    base_color = {r = 0.1, g = 0.1, b = 0.1},
    flow_color = {r = 0.1, g = 0.1, b = 0.1},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
	auto_barrel = false
  },
  {
    type = "item",
    name = "angels-plate-aluminium",
    icon = "__angelssmelting__/graphics/icons/plate-aluminium.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-aluminium-casting",
    order = "i",
    stack_size = 200
  },
  {
    type = "item",
    name = "angels-roll-aluminium",
    icon = "__angelssmelting__/graphics/icons/roll-aluminium.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-aluminium-casting",
    order = "j",
    stack_size = 200
  },
}
)

==> angelssmelting_0.4.6.zip: angelssmelting_0.4.6/prototypes/items/angels-aluminium.lua <==
data:extend(
{
  {
    type = "item",
    name = "bauxite-ore",
    icon = "__angelssmelting__/graphics/icons/ore-bauxite.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-aluminium",
    order = "a",
    stack_size = 200
  },
  {
    type = "item",
    name = "processed-aluminium",
    icon = "__angelssmelting__/graphics/icons/processed-aluminium.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-aluminium",
    order = "b",
    stack_size = 200
  },
  {
    type = "item",
    name = "pellet-aluminium",
    icon = "__angelssmelting__/graphics/icons/pellet-aluminium.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-aluminium",
    order = "c",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-sodium-aluminate",
    icon = "__angelssmelting__/graphics/icons/solid-sodium-aluminate.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-aluminium",
    order = "d",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-aluminium-hydroxide",
    icon = "__angelssmelting__/graphics/icons/solid-aluminium-hydroxide.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-aluminium",
    order = "e",
    stack_size = 200
  },
  {
    type = "item",
    name = "solid-aluminium-oxide",
    icon = "__angelssmelting__/graphics/icons/solid-aluminium-oxide.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-aluminium",
    order = "f",
    stack_size = 200
  },
  {
    type = "item",
    name = "ingot-aluminium",
    icon = "__angelssmelting__/graphics/icons/ingot-aluminium.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-aluminium",
    order = "g",
    stack_size = 200
  },
  {
    type = "item",
    name = "powder-aluminium",
    icon = "__angelssmelting__/graphics/icons/powder-aluminium.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-aluminium",
    order = "h",
    stack_size = 200
  },
  {
    type = "fluid",
    name = "liquid-molten-aluminium",
    icon = "__angelssmelting__/graphics/icons/molten-aluminium.png",
	icon_size = 32,
	default_temperature = 100,
    heat_capacity = "0KJ",
    base_color = {r = 172/255, g = 161/255, b = 84/255},
    flow_color = {r = 172/255, g = 161/255, b = 84/255},
    max_temperature = 100,
	pressure_to_speed_ratio = 0.4,
    flow_to_energy_ratio = 0.59,
	auto_barrel = false
  },
  {
    type = "item",
    name = "angels-plate-aluminium",
    icon = "__angelssmelting__/graphics/icons/plate-aluminium.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-aluminium-casting",
    order = "i",
    stack_size = 200
  },
  {
    type = "item",
    name = "angels-roll-aluminium",
    icon = "__angelssmelting__/graphics/icons/roll-aluminium.png",
	icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "angels-aluminium-casting",
    order = "j",
    stack_size = 200
  },
}
)
